@@ -723,7 +723,7 @@ spec = do
           ["rewrite", "--log-level=debug", "--log-lines=1", "--normalize"]
           [ intercalate
               "\n"
-              [ "[DEBUG]: Applied 'COPY' (44 nodes -> 39 nodes)"
+              [ "[DEBUG]: Applied 'copy' (44 nodes -> 39 nodes)"
               , "---| log is limited by --log-lines=1 option |---"
               ]
           ]
@@ -821,7 +821,7 @@ spec = do
         ["explain", "--rule=resources/copy.yaml"]
         [ unlines
             [ "\\begin{tabular}{rl}"
-            , "\\trrule{COPY}"
+            , "\\trrule{copy}"
             , "  { [[ B_1, \\tau -> ?, B_2 ]] ( \\tau -> e_1 ) }"
             , "  { [[ B_1, \\tau -> e_3, B_2 ]] }"
             , "  { if $ \\isnormal{ e_1 } $ }"
@@ -833,64 +833,64 @@ spec = do
     it "explains multiple rules" $
       testCLISucceeded
         ["explain", "--rule=resources/copy.yaml", "--rule=resources/alpha.yaml"]
-        ["\\begin{tabular}{rl}", "\\trrule{COPY}", "\\trrule{ALPHA}"]
+        ["\\begin{tabular}{rl}", "\\trrule{copy}", "\\trrule{alpha}"]
 
     it "explains normalization rules" $
       testCLISucceeded
         ["explain", "--normalize"]
         [ unlines
             [ "\\begin{tabular}{rl}"
-            , "\\trrule{ALPHA}"
+            , "\\trrule{alpha}"
             , "  { [[ B_1, \\tau_1 -> ?, B_2 ]] ( \\tau_2 -> e ) }"
             , "  { [[ B_1, \\tau_1 -> ?, B_2 ]] ( \\tau_1 -> e ) }"
             , "  { if $ \\indexof{ \\tau_2 } = \\vert B_1 \\vert $ }"
             , "  { }"
-            , "\\trrule{COPY}"
+            , "\\trrule{copy}"
             , "  { [[ B_1, \\tau -> ?, B_2 ]] ( \\tau -> e_1 ) }"
             , "  { [[ B_1, \\tau -> e_3, B_2 ]] }"
             , "  { if $ \\isnormal{ e_1 } $ }"
             , "  { where $ e_2 \\coloneqq \\scopeof{ e_1 } $ and $ e_3 \\coloneqq \\ctx{ e_1 }{ e_2 } $ }"
-            , "\\trrule{DC}"
+            , "\\trrule{dc}"
             , "  { T ( \\tau -> e ) }"
             , "  { T }"
             , "  { }"
             , "  { }"
-            , "\\trrule{DD}"
+            , "\\trrule{dd}"
             , "  { T . \\tau }"
             , "  { T }"
             , "  { }"
             , "  { }"
-            , "\\trrule{DOT}"
+            , "\\trrule{dot}"
             , "  { [[ B_1, \\tau -> e_1, B_2 ]] . \\tau }"
             , "  { e_2 ( ^ -> [[ B_1, \\tau -> e_1, B_2 ]] ) }"
             , "  { if $ \\isnormal{ e_1 } $ }"
             , "  { where $ e_2 \\coloneqq \\ctx{ e_1 }{ [[ B_1, \\tau -> e_1, B_2 ]] } $ }"
-            , "\\trrule{MISS}"
+            , "\\trrule{miss}"
             , "  { [[ B ]] ( \\tau -> e ) }"
             , "  { T }"
             , "  { if $ \\tau \\notin B \\;\\text{and}\\; \\tau \\notin [ ~0, ~1, \\dots ] $ }"
             , "  { }"
-            , "\\trrule{NULL}"
+            , "\\trrule{null}"
             , "  { [[ B_1, \\tau -> ?, B_2 ]] . \\tau }"
             , "  { T }"
             , "  { }"
             , "  { }"
-            , "\\trrule{OVER}"
+            , "\\trrule{over}"
             , "  { [[ B_1, \\tau -> e_1, B_2 ]] ( \\tau -> e_2 ) }"
             , "  { T }"
             , "  { if $ \\tau \\not= ^ $ }"
             , "  { }"
-            , "\\trrule{PHI}"
+            , "\\trrule{phi}"
             , "  { [[ B ]] . \\tau }"
             , "  { [[ B ]] . @ . \\tau }"
             , "  { if $ @ \\in B \\;\\text{and}\\; \\tau \\notin B $ }"
             , "  { }"
-            , "\\trrule{STAY}"
+            , "\\trrule{stay}"
             , "  { [[ B_1, ^ -> e_1, B_2 ]] ( ^ -> e_2 ) }"
             , "  { [[ B_1, ^ -> e_1, B_2 ]] }"
             , "  { }"
             , "  { }"
-            , "\\trrule{STOP}"
+            , "\\trrule{stop}"
             , "  { [[ B ]] . \\tau }"
             , "  { T }"
             , "  { if $ \\tau \\notin B \\;\\text{and}\\; @ \\notin B \\;\\text{and}\\; L \\notin B $ }"
